package com.playlet.system.service;

import java.util.List;
import com.playlet.system.domain.PlayletUserItem;
import com.baomidou.mybatisplus.extension.service.IService;

/**
 * 用户推广短剧Service接口
 *
 * @author ruoyi
 * @date 2024-04-15
 */
public interface IPlayletUserItemService extends IService<PlayletUserItem>
{
    /**
     * 查询用户推广短剧
     *
     * @param id 用户推广短剧主键
     * @return 用户推广短剧
     */
    public PlayletUserItem selectPlayletUserItemById(Long id);

    /**
     * 查询用户推广短剧列表
     *
     * @param playletUserItem 用户推广短剧
     * @return 用户推广短剧集合
     */
    public List<PlayletUserItem> selectPlayletUserItemList(PlayletUserItem playletUserItem);

    /**
     * 新增用户推广短剧
     *
     * @param playletUserItem 用户推广短剧
     * @return 结果
     */
    public int insertPlayletUserItem(PlayletUserItem playletUserItem);

    /**
     * 修改用户推广短剧
     *
     * @param playletUserItem 用户推广短剧
     * @return 结果
     */
    public int updatePlayletUserItem(PlayletUserItem playletUserItem);

    /**
     * 批量删除用户推广短剧
     *
     * @param ids 需要删除的用户推广短剧主键集合
     * @return 结果
     */
    public int deletePlayletUserItemByIds(String ids);

    /**
     * 删除用户推广短剧信息
     *
     * @param id 用户推广短剧主键
     * @return 结果
     */
    public int deletePlayletUserItemById(Long id);
}
